<?php
namespace Drupal\simple_sitemap_hidden_language;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\hidden_language\HiddenLanguageManager as HiddenLanguageHelper;

/**
 * Class HiddenLanguageManager.
 *
 * @package Drupal\simple_sitemap_hidden_language
 */
class HiddenLanguageManager {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  private $entityTypeManager;

  /**
   * The hidden language manager.
   *
   * @var \Drupal\hidden_language\HiddenLanguageManager
   */
  private $hiddenLanguageHelper;

  /**
   * HiddenLanguageManager constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   * @param Drupal\hidden_language\HiddenLanguageManager $hiddenLanguageHelper
   *   The hidden language manager.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager, HiddenLanguageHelper $hiddenLanguageHelper) {
    $this->entityTypeManager = $entityTypeManager;
    $this->hiddenLanguageHelper = $hiddenLanguageHelper;
  }

  /**
   * Resolve drupal internal route name by entity type and id.
   *
   * @param string $entityType
   *   Entity type used to load an entity object.
   * @param string $id
   *   Entity id used to load an entity object.
   *
   * @return false|string
   *   The route name or false.
   */
  public function getRouteNameByEntityTypeAndId(string $entityType, string $id) {
    try {
      $entity = $this->entityTypeManager->getStorage($entityType)->load($id);
      return $entity->toUrl()->getRouteName();
    }
    catch (\Exception $e) {
      return FALSE;
    }
  }

}
